Align embeddings across participants
align.embeddings.RdThis function takes a list of embeddings, one per participant, and procrustes-aligns each to a reference embedding.
Details
Each element of the list should contain embedding data from one participant,
as returned by the function get.combined. Each embedding must contain the
same items in the same order, and must be of the same dimension. The function
will procrustes-align each participant's embedding to the base participant,
specified by the baseno argument. The procrustes alignment permits rotation,
translation, scaling and reflection.