Get participant summary
get.participant.summary.RdThis function takes a list of triplet data of the kind returned by
get_combined and from it generates a dataframe summarizing information about
each participant in the study.
Arguments
- d
List of triplet data. Each element is data from one participant.
- irange
Vector indicating which elements of the list to include. Default is all.
- mintrial
Minimum number of trials needed to count as a complete record.
- accthresh
Accuracy threshould for check trials to pass quality check
- rtthresh
Threshold of log RT to pass quality check
Details
The summary will include participant ID, number of completed trials, mean
accuracy on check trials, and mean log(RT) across all trials. The arguments
accthresh and rtthresh set criteria for assessing the participant's data
quality. A mean log RT of 0 or less means participant was responding in under
one second on average, usually too fast for data to be real. Chance responding
will yield an accuracy of 0.5 on check trials, so a threshold of 0.8 means
participant was likely guessing on at least 40 percent of trials.
This function assumes standard triplet data naming conventions for column names.
Examples
#Path to example triplet data
fpath <- system.file("extdata", "cfd36_triplets_individual.csv", package = "tripletTools")
#Read the data
trips <- get.combined(fpath)
#> Warning: file("") only supports open = "w+" and open = "w+b": using the former
#> Error in read.table(file = file, header = header, sep = sep, quote = quote, dec = dec, fill = fill, comment.char = comment.char, ...): no lines available in input
#Compute summary
part.summary <- get.participant.summary(trips)
#> Error: object 'trips' not found
head(part.summary)
#> Error: object 'part.summary' not found