Make triplet names
make.tripnames.RdThis function creates a unique name for each triplet appearing in a triplet data frame.
Value
A character vector containing the unique triplet name for each trial in the triplet dataframe.
make.tripnames.RdThis function creates a unique name for each triplet appearing in a triplet data frame.
A character vector containing the unique triplet name for each trial in the triplet dataframe.